package core.api.controller;

import core.api.models.auth.SimpleStatusResponse;
import core.api.models.users.UserAddInfo;
import core.api.models.users.UserInfo;
import core.api.models.users.UserUpdateInfo;
import core.security.service.UserDetailsImpl;
import core.services.UserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;

@CrossOrigin(origins = "*", maxAge = 3600)
@RestController
@RequestMapping("/api")
public class UsersController {

    @Autowired
    private UserService userService;

    @GetMapping("/users")
    @PreAuthorize("hasRole('ADMIN')")
    public ResponseEntity<?> getUsers() {

        return ResponseEntity.ok(userService.getAllUserInfos());
    }

    @DeleteMapping("/users/{username}")
    @PreAuthorize("hasRole('ADMIN')")
    public ResponseEntity<?> deleteUser(@PathVariable String username) {
        boolean result = userService.deleteUserByName(username);

        if(result) {
            return ResponseEntity.ok(new SimpleStatusResponse("success"));
        } else {
            return ResponseEntity.status(404).build();
        }
    }

    @PostMapping("/users/{username}")
    @PreAuthorize("hasRole('ADMIN')")
    public ResponseEntity<?> updateUser(@PathVariable String username, @RequestBody UserUpdateInfo userUpdateInfo) {
        boolean result = userService.updateUser(username, userUpdateInfo);
        if(result) {
            return ResponseEntity.ok(new SimpleStatusResponse("success"));
        } else {
            return ResponseEntity.status(404).build();
        }
    }

    @PutMapping("/users")
    @PreAuthorize("hasRole('ADMIN')")
    public ResponseEntity<?> addUser(@Valid @RequestBody UserAddInfo userAddInfo) {
        boolean result = userService.addUser(userAddInfo);
        if(result) {
            return ResponseEntity.ok(new SimpleStatusResponse("success"));
        } else {
            return ResponseEntity.status(409).build();
        }
    }
}
