import {Component, OnInit} from '@angular/core';
import {TaskService, TaskTaskgroupInfo} from "../../api";
import {NavigationLink} from "../navigation-link-list/navigation-link-list.component";
import {MatSnackBar} from "@angular/material/snack-bar";
import {TaskEditorData} from "../tasks/task-editor/TaskEditorData";
import {TaskEditorComponent} from "../tasks/task-editor/task-editor.component";
import {MatDialog} from "@angular/material/dialog";

@Component({
  selector: 'app-upcoming-task-overview',
  templateUrl: './upcoming-task-overview.component.html',
  styleUrls: ['./upcoming-task-overview.component.css']
})
export class UpcomingTaskOverviewComponent implements OnInit{

  upcomingTasks: TaskTaskgroupInfo[] = []
  defaultNavigationLinkPath: NavigationLink[] = [
    {
      linkText: "Dashboard",
      routerLink: ['/']
    },
    {
      linkText: "Upcoming Tasks",
      routerLink: ["/upcoming"]
    }
  ]

  constructor(private taskService: TaskService,
              private snackbar: MatSnackBar,
              private dialog: MatDialog) {

  }

  ngOnInit(): void {
    this.taskService.tasksAllScopeDetailedGet("UPCOMING", true).subscribe({
      next: resp => {
        this.upcomingTasks = resp as TaskTaskgroupInfo[];
      }
    })
  }

  deleteTask(deletedTask: TaskTaskgroupInfo) {
    this.taskService.tasksTaskIDDelete(deletedTask.taskID).subscribe({
      next: resp => {
        this.upcomingTasks = this.upcomingTasks.filter(task => task.taskID !== deletedTask.taskID);
      },
      error: err => {
        if(err.status == 403) {
          this.snackbar.open("No permissions", "", {duration: 2000});
        } else if(err.status == 404) {
          this.snackbar.open("Not found", "", {duration: 2000});
        } else {
          this.snackbar.open("Unexpected error", "", {duration: 2000});
        }
      }
    })
  }

  editTask(editedTask: TaskTaskgroupInfo) {
    const taskEditorInfo: TaskEditorData = {
      task: editedTask,
      taskgroupID: editedTask.taskgroups[editedTask.taskgroups.length-1].taskgroupID
    };
    this.dialog.open(TaskEditorComponent, {data: taskEditorInfo, width: "600px"})
  }
}
